Ethereum class

Constructors

Ethereum()

Properties

autoRefreshOnNetworkChange ← bool
no getter
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
selectedAddress → String
no setter

Methods

chainId() → String
isConnected() → bool
listenerCount(String eventName) → Future
Return the number of listeners that are subscribed to event. If no event is provided, returns the total count of all events.
listeners() → Future
Return a list of listeners that are subscribed to event.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
off(String eventName, Function func) → Future
Add a listener to be triggered for only the next eventName event, at which time it will be removed.
on(String eventName, Function func) → Future
Add a listener to be triggered for each eventName event.
once(String eventName, Function func) → Future
Add a listener to be triggered for only the next eventName event, at which time it will be removed.
removeAllListeners(String? events) → Future
Add a listener to be triggered for only the next eventName event, at which time it will be removed.
request(RequestParams params) → Future
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited