BigNumber class

Available extensions

Constructors

BigNumber()

Properties

hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
toBigInt → BigInt

Available on BigNumber, provided by the BigNumberExtension extension

no setter
toInt → int

Available on BigNumber, provided by the BigNumberExtension extension

no setter

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toHexString() → String
toNumber() → int
toString() → String
A string representation of this object.
override

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Methods

from(String num) → BigNumber