BrowserProvider class

Inheritance

Constructors

BrowserProvider(Ethereum eth)

Properties

hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

getBalance(String address) → Future<BigNumber>
getBlockNumber() → Future<BigInt>
getNetwork() → Future<Network>
getSigner() → Future<Signer>
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited
waitForTransaction(String hash, [int confirms = 1]) → Future<TxReceipt>
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited