Contract class

Constructors

Contract(String address, List<String> abi, dynamic provider)

Properties

hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

balanceOf(String address) → Future<BigNumber>
connect(Signer signer) → Contract
listenerCount(String eventName) → Future
Return the number of listeners that are subscribed to event. If no event is provided, returns the total count of all events.
listeners() → Future
Return a list of listeners that are subscribed to event.
name() → Future<String>
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
off(String eventName, Function func) → Future
Unsubscribe listener to event.
on(String eventName, Function func) → Future
Subscribe to event calling listener when the event occurs.
once(String eventName, Function func) → Future
Subscribe once to event calling listener when the event occurs.
removeAllListeners(String? events) → Future
Unsubscribe all listeners for event. If no event is provided, all events are unsubscribed.
symbol() → Future<String>
tokenURI(BigNumber tokenID) → Future
toString() → String
A string representation of this object.
inherited
transfer(String to, String amount) → Future

Operators

operator ==(Object other) → bool
The equality operator.
inherited