Log class

Constructors

Log({int blockNumber, String blockHash, bool removed, int transactionLogIndex, String address, String data, List<String> topics, String transactionHash, String transactionIndex, String logIndex})
factory

Properties

address → String
no setter
blockHash → String
no setter
blockNumber → int
no setter
data → String
no setter
hashCode → int
The hash code for this object.
no setterinherited
logIndex → String
no setter
removed → bool
no setter
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
topics → List<String>
no setter
transactionHash → String
no setter
transactionIndex → String
no setter
transactionLogIndex → int
no setter

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited