TxParams class

Constructors

TxParams({String? to, String? value, String? gasLimit, String? gasPrice, String? nonce})
factory

Properties

gasLimit → String
no setter
gasPrice → String
no setter
hashCode → int
The hash code for this object.
no setterinherited
method → String
no setter
nonce → String
no setter
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
to → String
no setter
value → String
no setter

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited