TxReceipt class

Constructors

TxReceipt({String? to, String from, String? contractAddress, int transactionIndex, String? root, BigNumber gasUsed, String logsBloom, String blockHash, String transactionHash, List<Log> logs, int blockNumber, int confirmations, BigNumber cumulativeGasUsed, bool byzantium, int status})
factory

Properties

blockHash → String
no setter
blockNumber → int
no setter
byzantium → bool
no setter
confirmations → int
no setter
contractAddress → String?
no setter
cumulativeGasUsed → BigNumber
no setter
from → String
no setter
gasUsed → BigNumber
no setter
hashCode → int
The hash code for this object.
no setterinherited
logs → List<Log>
no setter
logsBloom → String
no setter
root → String?
no setter
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
status → int
no setter
to → String?
no setter
transactionHash → String
no setter
transactionIndex → int
no setter

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited